==> option-annotations-2.11.3-sources.jar: io/dekorate/option/config/JvmConfigFluentImpl.java <==
package io.dekorate.option.config;

import java.lang.Integer;
import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.SuppressWarnings;
import java.lang.Object;
import io.dekorate.option.annotation.SecureRandomSource;
import java.lang.String;
import java.lang.Boolean;
import io.dekorate.option.annotation.GarbageCollector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JvmConfigFluentImpl<A extends JvmConfigFluent<A>> extends ConfigurationFluentImpl<A> implements JvmConfigFluent<A>{
  public JvmConfigFluentImpl() {
  }
  public JvmConfigFluentImpl(io.dekorate.option.config.JvmConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withXms(instance.getXms()); 
    this.withXmx(instance.getXmx()); 
    this.withServer(instance.getServer()); 
    this.withUseStringDeduplication(instance.getUseStringDeduplication()); 
    this.withPreferIPv4Stack(instance.getPreferIPv4Stack()); 
    this.withHeapDumpOnOutOfMemoryError(instance.getHeapDumpOnOutOfMemoryError()); 
    this.withUseGCOverheadLimit(instance.getUseGCOverheadLimit()); 
    this.withGc(instance.getGc()); 
    this.withSecureRandom(instance.getSecureRandom()); 
  }
  private Integer xms;
  private java.lang.Integer xmx;
  private Boolean server;
  private java.lang.Boolean useStringDeduplication;
  private java.lang.Boolean preferIPv4Stack;
  private java.lang.Boolean heapDumpOnOutOfMemoryError;
  private java.lang.Boolean useGCOverheadLimit;
  private GarbageCollector gc;
  private SecureRandomSource secureRandom;
  public java.lang.Integer getXms() {
    return this.xms;
  }
  public A withXms(java.lang.Integer xms) {
    this.xms=xms; return (A) this;
  }
  public java.lang.Boolean hasXms() {
    return this.xms != null;
  }
  public java.lang.Integer getXmx() {
    return this.xmx;
  }
  public A withXmx(java.lang.Integer xmx) {
    this.xmx=xmx; return (A) this;
  }
  public java.lang.Boolean hasXmx() {
    return this.xmx != null;
  }
  public java.lang.Boolean getServer() {
    return this.server;
  }
  public A withServer(java.lang.Boolean server) {
    this.server=server; return (A) this;
  }
  public java.lang.Boolean hasServer() {
    return this.server != null;
  }
  public java.lang.Boolean getUseStringDeduplication() {
    return this.useStringDeduplication;
  }
  public A withUseStringDeduplication(java.lang.Boolean useStringDeduplication) {
    this.useStringDeduplication=useStringDeduplication; return (A) this;
  }
  public java.lang.Boolean hasUseStringDeduplication() {
    return this.useStringDeduplication != null;
  }
  public java.lang.Boolean getPreferIPv4Stack() {
    return this.preferIPv4Stack;
  }
  public A withPreferIPv4Stack(java.lang.Boolean preferIPv4Stack) {
    this.preferIPv4Stack=preferIPv4Stack; return (A) this;
  }
  public java.lang.Boolean hasPreferIPv4Stack() {
    return this.preferIPv4Stack != null;
  }
  public java.lang.Boolean getHeapDumpOnOutOfMemoryError() {
    return this.heapDumpOnOutOfMemoryError;
  }
  public A withHeapDumpOnOutOfMemoryError(java.lang.Boolean heapDumpOnOutOfMemoryError) {
    this.heapDumpOnOutOfMemoryError=heapDumpOnOutOfMemoryError; return (A) this;
  }
  public java.lang.Boolean hasHeapDumpOnOutOfMemoryError() {
    return this.heapDumpOnOutOfMemoryError != null;
  }
  public java.lang.Boolean getUseGCOverheadLimit() {
    return this.useGCOverheadLimit;
  }
  public A withUseGCOverheadLimit(java.lang.Boolean useGCOverheadLimit) {
    this.useGCOverheadLimit=useGCOverheadLimit; return (A) this;
  }
  public java.lang.Boolean hasUseGCOverheadLimit() {
    return this.useGCOverheadLimit != null;
  }
  public io.dekorate.option.annotation.GarbageCollector getGc() {
    return this.gc;
  }
  public A withGc(io.dekorate.option.annotation.GarbageCollector gc) {
    this.gc=gc; return (A) this;
  }
  public java.lang.Boolean hasGc() {
    return this.gc != null;
  }
  public io.dekorate.option.annotation.SecureRandomSource getSecureRandom() {
    return this.secureRandom;
  }
  public A withSecureRandom(io.dekorate.option.annotation.SecureRandomSource secureRandom) {
    this.secureRandom=secureRandom; return (A) this;
  }
  public java.lang.Boolean hasSecureRandom() {
    return this.secureRandom != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JvmConfigFluentImpl that = (JvmConfigFluentImpl) o;
    if (xms != null ? !xms.equals(that.xms) :that.xms != null) return false;
    if (xmx != null ? !xmx.equals(that.xmx) :that.xmx != null) return false;
    if (server != null ? !server.equals(that.server) :that.server != null) return false;
    if (useStringDeduplication != null ? !useStringDeduplication.equals(that.useStringDeduplication) :that.useStringDeduplication != null) return false;
    if (preferIPv4Stack != null ? !preferIPv4Stack.equals(that.preferIPv4Stack) :that.preferIPv4Stack != null) return false;
    if (heapDumpOnOutOfMemoryError != null ? !heapDumpOnOutOfMemoryError.equals(that.heapDumpOnOutOfMemoryError) :that.heapDumpOnOutOfMemoryError != null) return false;
    if (useGCOverheadLimit != null ? !useGCOverheadLimit.equals(that.useGCOverheadLimit) :that.useGCOverheadLimit != null) return false;
    if (gc != null ? !gc.equals(that.gc) :that.gc != null) return false;
    if (secureRandom != null ? !secureRandom.equals(that.secureRandom) :that.secureRandom != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(xms,  xmx,  server,  useStringDeduplication,  preferIPv4Stack,  heapDumpOnOutOfMemoryError,  useGCOverheadLimit,  gc,  secureRandom,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (xms != null) { sb.append("xms:"); sb.append(xms + ","); }
    if (xmx != null) { sb.append("xmx:"); sb.append(xmx + ","); }
    if (server != null) { sb.append("server:"); sb.append(server + ","); }
    if (useStringDeduplication != null) { sb.append("useStringDeduplication:"); sb.append(useStringDeduplication + ","); }
    if (preferIPv4Stack != null) { sb.append("preferIPv4Stack:"); sb.append(preferIPv4Stack + ","); }
    if (heapDumpOnOutOfMemoryError != null) { sb.append("heapDumpOnOutOfMemoryError:"); sb.append(heapDumpOnOutOfMemoryError + ","); }
    if (useGCOverheadLimit != null) { sb.append("useGCOverheadLimit:"); sb.append(useGCOverheadLimit + ","); }
    if (gc != null) { sb.append("gc:"); sb.append(gc + ","); }
    if (secureRandom != null) { sb.append("secureRandom:"); sb.append(secureRandom); }
    sb.append("}");
    return sb.toString();
  }
  public A withServer() {
    return withServer(true);
  }
  public A withUseStringDeduplication() {
    return withUseStringDeduplication(true);
  }
  public A withPreferIPv4Stack() {
    return withPreferIPv4Stack(true);
  }
  public A withHeapDumpOnOutOfMemoryError() {
    return withHeapDumpOnOutOfMemoryError(true);
  }
  public A withUseGCOverheadLimit() {
    return withUseGCOverheadLimit(true);
  }
  
}

==> option-annotations-3.2.0-sources.jar: io/dekorate/option/config/JvmConfigFluentImpl.java <==
package io.dekorate.option.config;

import java.lang.Integer;
import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.SuppressWarnings;
import java.lang.Object;
import io.dekorate.option.annotation.SecureRandomSource;
import java.lang.String;
import java.lang.Boolean;
import io.dekorate.option.annotation.GarbageCollector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JvmConfigFluentImpl<A extends JvmConfigFluent<A>> extends ConfigurationFluentImpl<A> implements JvmConfigFluent<A>{
  public JvmConfigFluentImpl() {
  }
  public JvmConfigFluentImpl(JvmConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withXms(instance.getXms()); 
    this.withXmx(instance.getXmx()); 
    this.withServer(instance.getServer()); 
    this.withUseStringDeduplication(instance.getUseStringDeduplication()); 
    this.withPreferIPv4Stack(instance.getPreferIPv4Stack()); 
    this.withHeapDumpOnOutOfMemoryError(instance.getHeapDumpOnOutOfMemoryError()); 
    this.withUseGCOverheadLimit(instance.getUseGCOverheadLimit()); 
    this.withGc(instance.getGc()); 
    this.withSecureRandom(instance.getSecureRandom()); 
  }
  private Integer xms;
  private Integer xmx;
  private Boolean server;
  private Boolean useStringDeduplication;
  private Boolean preferIPv4Stack;
  private Boolean heapDumpOnOutOfMemoryError;
  private Boolean useGCOverheadLimit;
  private GarbageCollector gc;
  private SecureRandomSource secureRandom;
  public Integer getXms() {
    return this.xms;
  }
  public A withXms(Integer xms) {
    this.xms=xms; return (A) this;
  }
  public Boolean hasXms() {
    return this.xms != null;
  }
  public Integer getXmx() {
    return this.xmx;
  }
  public A withXmx(Integer xmx) {
    this.xmx=xmx; return (A) this;
  }
  public Boolean hasXmx() {
    return this.xmx != null;
  }
  public Boolean getServer() {
    return this.server;
  }
  public A withServer(Boolean server) {
    this.server=server; return (A) this;
  }
  public Boolean hasServer() {
    return this.server != null;
  }
  public Boolean getUseStringDeduplication() {
    return this.useStringDeduplication;
  }
  public A withUseStringDeduplication(Boolean useStringDeduplication) {
    this.useStringDeduplication=useStringDeduplication; return (A) this;
  }
  public Boolean hasUseStringDeduplication() {
    return this.useStringDeduplication != null;
  }
  public Boolean getPreferIPv4Stack() {
    return this.preferIPv4Stack;
  }
  public A withPreferIPv4Stack(Boolean preferIPv4Stack) {
    this.preferIPv4Stack=preferIPv4Stack; return (A) this;
  }
  public Boolean hasPreferIPv4Stack() {
    return this.preferIPv4Stack != null;
  }
  public Boolean getHeapDumpOnOutOfMemoryError() {
    return this.heapDumpOnOutOfMemoryError;
  }
  public A withHeapDumpOnOutOfMemoryError(Boolean heapDumpOnOutOfMemoryError) {
    this.heapDumpOnOutOfMemoryError=heapDumpOnOutOfMemoryError; return (A) this;
  }
  public Boolean hasHeapDumpOnOutOfMemoryError() {
    return this.heapDumpOnOutOfMemoryError != null;
  }
  public Boolean getUseGCOverheadLimit() {
    return this.useGCOverheadLimit;
  }
  public A withUseGCOverheadLimit(Boolean useGCOverheadLimit) {
    this.useGCOverheadLimit=useGCOverheadLimit; return (A) this;
  }
  public Boolean hasUseGCOverheadLimit() {
    return this.useGCOverheadLimit != null;
  }
  public GarbageCollector getGc() {
    return this.gc;
  }
  public A withGc(GarbageCollector gc) {
    this.gc=gc; return (A) this;
  }
  public Boolean hasGc() {
    return this.gc != null;
  }
  public SecureRandomSource getSecureRandom() {
    return this.secureRandom;
  }
  public A withSecureRandom(SecureRandomSource secureRandom) {
    this.secureRandom=secureRandom; return (A) this;
  }
  public Boolean hasSecureRandom() {
    return this.secureRandom != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JvmConfigFluentImpl that = (JvmConfigFluentImpl) o;
    if (xms != null ? !xms.equals(that.xms) :that.xms != null) return false;
    if (xmx != null ? !xmx.equals(that.xmx) :that.xmx != null) return false;
    if (server != null ? !server.equals(that.server) :that.server != null) return false;
    if (useStringDeduplication != null ? !useStringDeduplication.equals(that.useStringDeduplication) :that.useStringDeduplication != null) return false;
    if (preferIPv4Stack != null ? !preferIPv4Stack.equals(that.preferIPv4Stack) :that.preferIPv4Stack != null) return false;
    if (heapDumpOnOutOfMemoryError != null ? !heapDumpOnOutOfMemoryError.equals(that.heapDumpOnOutOfMemoryError) :that.heapDumpOnOutOfMemoryError != null) return false;
    if (useGCOverheadLimit != null ? !useGCOverheadLimit.equals(that.useGCOverheadLimit) :that.useGCOverheadLimit != null) return false;
    if (gc != null ? !gc.equals(that.gc) :that.gc != null) return false;
    if (secureRandom != null ? !secureRandom.equals(that.secureRandom) :that.secureRandom != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(xms,  xmx,  server,  useStringDeduplication,  preferIPv4Stack,  heapDumpOnOutOfMemoryError,  useGCOverheadLimit,  gc,  secureRandom,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (xms != null) { sb.append("xms:"); sb.append(xms + ","); }
    if (xmx != null) { sb.append("xmx:"); sb.append(xmx + ","); }
    if (server != null) { sb.append("server:"); sb.append(server + ","); }
    if (useStringDeduplication != null) { sb.append("useStringDeduplication:"); sb.append(useStringDeduplication + ","); }
    if (preferIPv4Stack != null) { sb.append("preferIPv4Stack:"); sb.append(preferIPv4Stack + ","); }
    if (heapDumpOnOutOfMemoryError != null) { sb.append("heapDumpOnOutOfMemoryError:"); sb.append(heapDumpOnOutOfMemoryError + ","); }
    if (useGCOverheadLimit != null) { sb.append("useGCOverheadLimit:"); sb.append(useGCOverheadLimit + ","); }
    if (gc != null) { sb.append("gc:"); sb.append(gc + ","); }
    if (secureRandom != null) { sb.append("secureRandom:"); sb.append(secureRandom); }
    sb.append("}");
    return sb.toString();
  }
  public A withServer() {
    return withServer(true);
  }
  public A withUseStringDeduplication() {
    return withUseStringDeduplication(true);
  }
  public A withPreferIPv4Stack() {
    return withPreferIPv4Stack(true);
  }
  public A withHeapDumpOnOutOfMemoryError() {
    return withHeapDumpOnOutOfMemoryError(true);
  }
  public A withUseGCOverheadLimit() {
    return withUseGCOverheadLimit(true);
  }
  
}
